@@ -33,7 +33,7 @@ static const TDECmdLineOptions options[] =
 
 extern "C"
 {
-    KDE_EXPORT int kdemain(int argc, char **argv) {
+    TDE_EXPORT int kdemain(int argc, char **argv) {
         TDEInstance instance( "tdeio_bluetooth" );
         kdDebug() << "*** Starting tdeio_bluetooth " << endl;
         if (argc != 4) {
