@@ -164,9 +164,9 @@ UDSEntry Obex::createUDSEntry(const TQMap<TQString, TQT_DBusData> &map)
         if (mit.key() == "Group-perm")
         {
             TQString v = mit.data().toVariant().value.toString();
-            if (v.contains('R', FALSE))
+            if (v.contains('R', false))
                 mode |= S_IRGRP;
-            if (v.contains('W', FALSE))
+            if (v.contains('W', false))
                 mode |= S_IWGRP;
         }
         if (mit.key() == "Modified")
@@ -193,9 +193,9 @@ UDSEntry Obex::createUDSEntry(const TQMap<TQString, TQT_DBusData> &map)
         if (mit.key() == "Other-perm")
         {
             TQString v = mit.data().toVariant().value.toString();
-            if (v.contains('R', FALSE))
+            if (v.contains('R', false))
                 mode |= S_IROTH;
-            if (v.contains('W', FALSE))
+            if (v.contains('W', false))
                 mode |= S_IWOTH;
         }
         if (mit.key() == "Type")
@@ -214,9 +214,9 @@ UDSEntry Obex::createUDSEntry(const TQMap<TQString, TQT_DBusData> &map)
         if (mit.key() == "User-perm")
         {
             TQString v = mit.data().toVariant().value.toString();
-            if (v.contains('R', FALSE))
+            if (v.contains('R', false))
                 mode |= S_IRUSR;
-            if (v.contains('W', FALSE))
+            if (v.contains('W', false))
                 mode |= S_IWUSR;
         }
     }
