@@ -42,7 +42,7 @@ static const TDECmdLineOptions options[] = { { "+protocol", I18N_NOOP(
                 "+app", I18N_NOOP("Socket name"), 0 }, TDECmdLineLastOption };
 
 extern "C" {
-    int KDE_EXPORT kdemain( int argc, char **argv )
+    int TDE_EXPORT kdemain( int argc, char **argv )
     {
         // TDEApplication is necessary to use other ioslaves
         putenv(strdup("SESSION_MANAGER="));
